searchData={"items":[{"type":"module","title":"StreamingDelta","doc":"# StreamingDelta\n\nCharacter-by-character (chunks) conversion of Markdown into a [Delta](https://quilljs.com/docs/delta). \nThis is useful when streaming Markdown from an LLM response, as it allows just the delta changes to be sent to the browser.\n\n# Parses\n\n- Italic\n- Bold\n- Headings\n- Unordered List\n- Ordered list\n- Source refs (Not official Markdown useful when you want an LLM to return citations from the context .eg. some text [1].)\n- Follow up questions (Not official Markdown useful when you want to extract text that returned in brackets .eg. < >.)\n- Extractions (Not official Markdown useful when you want to extract a section of text from the main text)\n\ntest/streaming_delta/parser_test.exs has many examples that can be used to understand the text formats you would want to provide to an LLM so the right formats our output.\n\nStreamingDelta.parse_chunk is used to parse a chunk and StreamingDelta.Streaming struct is the accumulateur.\nTo parse a stream of updates you would pass the next chunk and the returnd StreamingDelta.Streaming struct from the previous chunk in a loop.\n\nTo get the difference between two chunks you can use StreamingDelta.Streaming.diffs by passing in the StreamingDelta.Streaming struct for the previous chunk and StreamingDelta.Streaming struct for the latest chunk.","ref":"StreamingDelta.html"},{"type":"module","title":"Installation - StreamingDelta","doc":"```elixir\ndef deps do\n  [\n    {:streaming_delta, \"~> 0.1.0\"}\n  ]\nend\n```\n\n# Todo\n\n- Add finished option to close the buffer and concat on to raw\n- Handle white space stars in list that canceled out by white space .eg. 1. * Not italic \n- Links in square brackets\n- stripe white space on neasted lists\n- stripe white space on orderd list between list and number\n- Provied example LLM prompts for the propriety format","ref":"StreamingDelta.html#module-installation"},{"type":"module","title":"Examples - StreamingDelta","doc":"iex> StreamingDelta.parse_chunk(\"word\", %StreamingDelta.Streaming{})\n    %StreamingDelta.Streaming{delta: [%{\"insert\" => \"word\"}], raw: \"word\"}\n\n    iex> StreamingDelta.parse_chunk(\"*word*\\n\", %StreamingDelta.Streaming{})\n    %StreamingDelta.Streaming{delta: [%{\"insert\" => \"word\", \"attributes\" => %{\"italic\" => true}}], raw: \"*word*\", buffer: [\"\\n\"]}","ref":"StreamingDelta.html#module-examples"},{"type":"function","title":"StreamingDelta.parse_chunk/3","doc":"See  StreamingDelta.Parser.parse_chunk/3 .","ref":"StreamingDelta.html#parse_chunk/3"},{"type":"function","title":"StreamingDelta.parse_chunks/3","doc":"See  StreamingDelta.Parser.parse_chunks/3 .","ref":"StreamingDelta.html#parse_chunks/3"},{"type":"module","title":"StreamingDelta.Parser","doc":"","ref":"StreamingDelta.Parser.html"},{"type":"function","title":"StreamingDelta.Parser.parse_chunk/3","doc":"","ref":"StreamingDelta.Parser.html#parse_chunk/3"},{"type":"function","title":"StreamingDelta.Parser.parse_chunks/3","doc":"","ref":"StreamingDelta.Parser.html#parse_chunks/3"},{"type":"module","title":"StreamingDelta.Streaming","doc":"","ref":"StreamingDelta.Streaming.html"},{"type":"function","title":"StreamingDelta.Streaming.diffs/2","doc":"","ref":"StreamingDelta.Streaming.html#diffs/2"},{"type":"type","title":"StreamingDelta.Streaming.t/0","doc":"","ref":"StreamingDelta.Streaming.html#t:t/0"},{"type":"module","title":"StreamingDelta.Streaming.DeltaDiff","doc":"","ref":"StreamingDelta.Streaming.DeltaDiff.html"},{"type":"type","title":"StreamingDelta.Streaming.DeltaDiff.t/0","doc":"","ref":"StreamingDelta.Streaming.DeltaDiff.html#t:t/0"},{"type":"module","title":"StreamingDelta.Streaming.Extraction","doc":"","ref":"StreamingDelta.Streaming.Extraction.html"},{"type":"type","title":"StreamingDelta.Streaming.Extraction.t/0","doc":"","ref":"StreamingDelta.Streaming.Extraction.html#t:t/0"},{"type":"module","title":"StreamingDelta.Streaming.ExtractionDiff","doc":"","ref":"StreamingDelta.Streaming.ExtractionDiff.html"},{"type":"type","title":"StreamingDelta.Streaming.ExtractionDiff.t/0","doc":"","ref":"StreamingDelta.Streaming.ExtractionDiff.html#t:t/0"},{"type":"module","title":"StreamingDelta.Streaming.Source","doc":"","ref":"StreamingDelta.Streaming.Source.html"},{"type":"type","title":"StreamingDelta.Streaming.Source.t/0","doc":"","ref":"StreamingDelta.Streaming.Source.html#t:t/0"},{"type":"function","title":"StreamingDelta.Streaming.Source.tokens_count/1","doc":"","ref":"StreamingDelta.Streaming.Source.html#tokens_count/1"},{"type":"module","title":"StreamingDelta.Streaming.Source.CoverImage","doc":"","ref":"StreamingDelta.Streaming.Source.CoverImage.html"},{"type":"function","title":"StreamingDelta.Streaming.Source.CoverImage.build/1","doc":"","ref":"StreamingDelta.Streaming.Source.CoverImage.html#build/1"},{"type":"type","title":"StreamingDelta.Streaming.Source.CoverImage.t/0","doc":"","ref":"StreamingDelta.Streaming.Source.CoverImage.html#t:t/0"},{"type":"module","title":"StreamingDelta.Streaming.Source.Thumbnail","doc":"","ref":"StreamingDelta.Streaming.Source.Thumbnail.html"},{"type":"function","title":"StreamingDelta.Streaming.Source.Thumbnail.build/1","doc":"","ref":"StreamingDelta.Streaming.Source.Thumbnail.html#build/1"},{"type":"type","title":"StreamingDelta.Streaming.Source.Thumbnail.t/0","doc":"","ref":"StreamingDelta.Streaming.Source.Thumbnail.html#t:t/0"},{"type":"extras","title":"StreamingDelta","doc":"# StreamingDelta\n\nCharacter-by-character (chunks) conversion of Markdown into a [Delta](https://quilljs.com/docs/delta). \nThis is useful when streaming Markdown from an LLM response, as it allows just the delta changes to be sent to the browser.\n\n# Parses\n\n- Italic\n- Bold\n- Headings\n- Unordered List\n- Ordered list\n- Source refs (Not official Markdown useful when you want an LLM to return citations from the context .eg. some text [1].)\n- Follow up questions (Not official Markdown useful when you want to extract text that returned in brackets .eg. < >.)\n- Extractions (Not official Markdown useful when you want to extract a section of text from the main text)\n\ntest/streaming_delta/parser_test.exs has many examples that can be used to understand the text formats you would want to provide to an LLM so the right formats our output.\n\nStreamingDelta.parse_chunk is used to parse a chunk and StreamingDelta.Streaming struct is the accumulateur.\nTo parse a stream of updates you would pass the next chunk and the returnd StreamingDelta.Streaming struct from the previous chunk in a loop.\n\nTo get the difference between two chunks you can use StreamingDelta.Streaming.diffs by passing in the StreamingDelta.Streaming struct for the previous chunk and StreamingDelta.Streaming struct for the latest chunk.","ref":"readme.html"},{"type":"extras","title":"Installation - StreamingDelta","doc":"```elixir\ndef deps do\n  [\n    {:streaming_delta, \"~> 0.1.0\"}\n  ]\nend\n```\n\n# Todo\n\n- Add finished option to close the buffer and concat on to raw\n- Handle white space stars in list that canceled out by white space .eg. 1. * Not italic \n- Links in square brackets\n- stripe white space on neasted lists\n- stripe white space on orderd list between list and number\n- Provied example LLM prompts for the propriety format","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}